Vbox Example
===============================================================================

:download:`vbox.enaml <../../../examples/layout/basic/vbox.enaml>`

.. literalinclude:: ../../../examples/layout/basic/vbox.enaml
    :language: python

::

 $ enaml-run vbox.enaml

.. image:: images/vbox.png
